# Shimmy

An API conversion tool for popular external reinforcement learning environments to [Gymnasium](https://github.com/farama-Foundation/gymnasium) and [PettingZoo](https://github.com/farama-Foundation/pettingZoo/) APIs

Supported APIs for Gymnasium
* OpenAI Gym
* DMEnvs including DMControl

Supported APIs for PettingZoo
* OpenSpiel

We are open to supporting more external APIs, please create an issue or pull request for the API
